# Changelog

<!--next-version-placeholder-->

## v2.1.0 (2021-03-31)
### Feature
* Only configure caching if requested ([`109f430`](https://github.com/kalekundert/autoprop/commit/109f430fd286e139ed2fef02777d106be2334df2))

### Fix
* Don't have *every* static/class method invalidate the cache ([`a231052`](https://github.com/kalekundert/autoprop/commit/a231052fb038260055ad5bdaa860e2e25eb4f5a3))

### Documentation
* Document the caching system ([`1974c42`](https://github.com/kalekundert/autoprop/commit/1974c42e0f33859c6c282869cbb861b2c9a8a3de))

## v2.0.0 (2021-03-30)
### Feature
* Drop support for python 3.5 ([`d4781cb`](https://github.com/kalekundert/autoprop/commit/d4781cb489a0a74987ca96eb390d4e1dd507ff47))
* Implement caching policies ([`a05726a`](https://github.com/kalekundert/autoprop/commit/a05726aa96ccce670274430180272dd2c72c3df5))

### Breaking
* Drop support for python2.  ([`a05726a`](https://github.com/kalekundert/autoprop/commit/a05726aa96ccce670274430180272dd2c72c3df5))

### Documentation
* Remove python2 badge ([`815c60d`](https://github.com/kalekundert/autoprop/commit/815c60d5d81d82f567baba2df4b927bc4cbbc224))
